@@ -3,7 +3,7 @@
  * fastpath.h
  *
  *
- * Portions Copyright (c) 1996-2012, PostgreSQL Global Development Group
+ * Portions Copyright (c) 1996-2014, PostgreSQL Global Development Group
  * Portions Copyright (c) 1994, Regents of the University of California
  *
  * src/include/tcop/fastpath.h
@@ -16,6 +16,6 @@
 #include "lib/stringinfo.h"
 
 extern int GetOldFunctionMessage(StringInfo buf);
-extern int	HandleFunctionRequest(StringInfo msgBuf);
+extern void HandleFunctionRequest(StringInfo msgBuf);
 
 #endif   /* FASTPATH_H */
